@@ -59,6 +59,7 @@ class Reddit(object):
         self._cookies = None
         self._respect = respect
         self._last_request_time = None
+        self._username = None
         
         if respect and not user_agent:
             raise ValueError('must specify user_agent to respect reddit rules')
@@ -495,7 +496,7 @@ class Reddit(object):
     def delete(self, id_):
         """Login required.  Send POST to delete an object.  Returns :class:`requests.Response` object.
         
-        URL: ``http://www.reddit.com/api/delete/``
+        URL: ``http://www.reddit.com/api/del/``
         
         :param sr: full id of object to delete   
         """
